@@ -5,7 +5,7 @@ use warnings;
 
 package Class::Enumeration;
 
-$Class::Enumeration::VERSION = 'v1.0.0';
+$Class::Enumeration::VERSION = 'v1.0.1';
 
 use overload
   '""'     => 'to_string',
@@ -19,22 +19,6 @@ use Scalar::Util ();
 # $self == enum object
 # $class == enum class
 
-sub _new { ## no critic ( ProhibitUnusedPrivateSubroutines )
-  my ( $class, $ordinal, $name, $attributes ) = @_;
-
-  Carp::croak 'The enum object name cannot be empty, stopped'
-    if $name eq '';
-  $attributes = {} unless defined $attributes;
-  # Will raise a FATAL warning ("Not a HASH reference at ...") if $attribute is
-  # not a HASH reference
-  for ( keys %$attributes ) {
-    Carp::croak "Overriding the implicit '$_' enum object attribute is forbidden, stopped"
-      if $_ eq 'ordinal' or $_ eq 'name';
-  }
-
-  bless { ordinal => $ordinal, name => $name, %$attributes }, $class
-}
-
 sub name {
   my ( $self ) = @_;
 
@@ -58,7 +42,7 @@ sub values { ## no critic ( ProhibitBuiltinHomonyms )
   my ( $class ) = @_;
 
   no strict 'refs'; ## no critic ( ProhibitNoStrict )
-  sort { $a->ordinal <=> $b->ordinal } @{ *{ "$class\::Values" }{ ARRAY } }
+  sort { $a->ordinal <=> $b->ordinal } $class->_values
 }
 
 sub names {
@@ -73,6 +57,26 @@ sub to_string {
   $self->name
 }
 
+sub _new { ## no critic ( ProhibitUnusedPrivateSubroutines )
+  my ( $class, $ordinal, $name, $attributes ) = @_;
+
+  Carp::croak 'The enum object name cannot be empty, stopped'
+    if $name eq '';
+  $attributes = {} unless defined $attributes;
+  # Will raise a FATAL warning ("Not a HASH reference at ...") if $attribute is
+  # not a HASH reference
+  for ( keys %$attributes ) {
+    Carp::croak "Overriding the implicit '$_' enum object attribute is forbidden, stopped"
+      if $_ eq 'ordinal' or $_ eq 'name';
+  }
+
+  bless { ordinal => $ordinal, name => $name, %$attributes }, $class
+}
+
+sub _values {
+  Carp::croak "'_values()' method not implemented by child class, stopped"
+}
+
 sub _is_identical_to {
   my ( $self, $object, $swapFlag ) = @_;
 
